==> Paws-0.25.tar.gz: Paws-0.25/lib/Paws/IAM/DeleteAccessKey.pm <==

package Paws::IAM::DeleteAccessKey;
  use Moose;
  has AccessKeyId => (is => 'ro', isa => 'Str', required => 1);
  has UserName => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteAccessKey');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::DeleteAccessKey - Arguments for method DeleteAccessKey on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteAccessKey on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method DeleteAccessKey.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteAccessKey.

As an example:

  $service_obj->DeleteAccessKey(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessKeyId => Str

The access key ID for the access key ID and secret access key you want
to delete.



=head2 UserName => Str

The name of the user whose key you want to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteAccessKey in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.26.tar.gz: Paws-0.26/lib/Paws/IAM/DeleteAccessKey.pm <==

package Paws::IAM::DeleteAccessKey;
  use Moose;
  has AccessKeyId => (is => 'ro', isa => 'Str', required => 1);
  has UserName => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteAccessKey');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::DeleteAccessKey - Arguments for method DeleteAccessKey on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteAccessKey on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method DeleteAccessKey.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteAccessKey.

As an example:

  $service_obj->DeleteAccessKey(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AccessKeyId => Str

The access key ID for the access key ID and secret access key you want
to delete.

The regex pattern for this parameter is a string of characters that can
consist of any upper or lowercased letter or digit.



=head2 UserName => Str

The name of the user whose access key pair you want to delete.

The regex pattern for this parameter is a string of characters
consisting of upper and lowercase alphanumeric characters with no
spaces. You can also include any of the following characters: =,.@-




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteAccessKey in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
